#ifndef SPEEDGRAPH_H
#define SPEEDGRAPH_H

#include "AbstractChart.h"

#include <rx/columbus/ColumbusModel.h>

class SpeedGraphPrivate;

class SpeedGraph : public AbstractChart
{
    Q_OBJECT

public:
    explicit SpeedGraph(QWidget *parent = 0);

    ColumbusModel* model() const;

public slots:
    void setModel(ColumbusModel *model);

protected:
    void paintEvent(QPaintEvent *event);

private:
    SpeedGraphPrivate *d;
};

#endif // SPEEDGRAPH_H
